Developer documentation
=======================

.. include:: ../../CONTRIBUTING.md
   :parser: myst_parser.sphinx_

Table of contents
-----------------

.. toctree::
   :maxdepth: 2

   getting-started
   coding-conventions
   dependency-management
   testing
